# coding:utf-8
import csv
import json
import logging
import os

from ruamel import yaml

from shangqi_cloud_lib.context import config


def remove_file(file_name):
    file_path = os.path.join(config.project_path, file_name)
    if os.path.exists(file_path):
        os.remove(file_path)


def write_csv(file_path, data_list, title_list=None, encode="utf-8"):
    if title_list is None:
        title_list = []
    f = open(file_path, 'w', encoding=encode, newline='')
    csv_writer = csv.writer(f)
    if len(title_list) > 0:
        csv_writer.writerow(title_list)
    for item in data_list:
        csv_writer.writerow(item)
    f.close()


def write_json(file_name, data, base_path=None, no_base=False):
    if not base_path:
        base_path = config.project_path
    if no_base:
        file_path = file_name
    else:
        file_path = os.path.join(base_path, file_name)
    path_arr = str(file_name).split(os.path.sep)
    if len(path_arr) > 1:
        path = os.path.join(base_path, os.path.sep.join(path_arr[0:-1]))
    else:
        path = base_path
    if not os.path.exists(path):
        os.makedirs(path)
    if not isinstance(data, str):
        data = json.dumps(data, ensure_ascii=False)
    f = open(file_path, 'w', encoding='utf-8')
    f.write(data)
    f.close()


def read_json(file_name, base_path=None, no_base=False):
    if not base_path:
        base_path = config.project_path
    if no_base:
        file_path = file_name
    else:
        file_path = os.path.join(base_path, file_name)
    if os.path.exists(file_path):
        with open(file_path, 'r', encoding='utf-8') as f:
            context = f.read()
            return json.loads(context)
    return {}


# 读取yaml
def read_yaml(file_path):
    try:
        if not os.path.exists(file_path):
            return None
        f = open(file_path, 'r', encoding='utf-8')
        cont = f.read()
        return yaml.round_trip_load(cont)
    except Exception as e:
        logging.error(str(e))
        return None


# 写入yaml
def write_yaml(file_path, data):
    fw = open(file_path, 'w', encoding='utf-8')
    yaml.round_trip_dump(data, fw, allow_unicode=True)


def write_text(file_path, text):
    f = open(file_path, 'w', encoding='utf-8')
    f.write(text)
    f.close()


def read_text(file_path):
    f = open(file_path, 'r', encoding='utf-8')
    text = f.read()
    f.close()
    return text


def file_upload(file_metas, path, check_name_func=None):
    filename = file_metas[0]['filename']
    if not check_name_func(filename):
        raise NameError(f"上传文件{filename}不符合格式！")
    if not os.path.exists(path):
        os.makedirs(path)
    file_path = os.path.join(path, filename)
    if os.path.exists(file_path):
        os.remove(file_path)
    with open(file_path, 'wb') as up:
        up.write(file_metas[0]['body'])
    return file_path


def get_files(path, suffix):
    return [os.path.join(root, file) for root, dirs, files in os.walk(path) for file in files if file.endswith(suffix)]



# coding: --utf-8--
import os

from setuptools import setup, find_packages

# install requirements
with open('requirements.txt') as f:
    requirements = [x.strip() for x in f.readlines()]

name = "shangqi_cloud_lib"


def gen_data_files(*dirs):
    results = ["requirements.txt"]

    for src_dir in dirs:
        for root, dirs, files in os.walk(name + os.path.sep + src_dir):
            results.append((root, map(lambda f: root + os.path.sep + f, files)))
    print(results)
    return results


setup(
    name=name,
    version='0.1.6',
    description=u'基于tornado封装简易开发框架，可自动化生成API文档',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3',
        'Framework :: Django'],
    keywords='tornado web',
    author='shangqi',
    #author_email='',
    #url="",
    include_package_data=True,
    data_files=gen_data_files("templates"),
    packages=find_packages(),
    install_requires=requirements,
)
